@@ -96,6 +96,9 @@ class API:
             self.__driver.switch_to.default_content()
 
     def _solve_audio_challenge(self) -> None:
+        if self.__driver.find_element(by='class name', value='rc-doscaptcha-header-text').text == 'Try again later':
+            raise RecaptchaException('Google has detected automated queries. Try again later.')
+
         # Locate audio challenge download link and download it via requests in to temporary files
         download_link = self._wait_for_element(
             tag='class name',
